==> babolo-parser-0.02.tar.gz: babolo-parser-0.02/freeparm.c <==
/*-
 * Copyright (C)2003 @BABOLO http://www.babolo.ru/
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef lint
static const char copyright[] = "\
@(#)Copyright (C)2003 @BABOLO http://www.babolo.ru/\n\
@(#)All rights reserved.\n";
static const char rcsid[] = "$Id: freeparm.c,v 1.2 2004/01/25 07:28:47 babolo Exp $";
#endif /* not lint */

#include <sys/types.h>
#include <stdlib.h>
#include <stdio.h>
#include <babolo/BLINflag.h>
#include "parser.h"

void
babolo_freeparm(struct babolo_parm *parm) {
    int i;

    ifBLIN_QV3(parm->flag) fprintf( stderr
                                  , "+babolo_freeparm flag=%06X argc=%d\n"
                                  , parm->flag
                                  , parm->argc
                                  );
    if  (parm && parm->argv) {
        if  (parm->flag & Bpars_CHNK) free(*parm->argv);
        else
            for (i = 0; i < parm->argc; i++) {
                free(parm->argv[i]);
            }
        free(parm->argv);
    }
    free(parm);
    ifBLIN_QV3(parm->flag) fprintf(stderr, "-babolo_freeparm\n");
}

==> babolo-parser-1.04.tar.gz: babolo-parser-1.04/freeparm.c <==
/*-
 * Copyright (C)2003 @BABOLO http://www.babolo.ru/
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef lint
static const char copyright[] = "\
@(#)Copyright (C)2003 @BABOLO http://www.babolo.ru/\n\
@(#)All rights reserved.\n";
static const char rcsid[] = "$Id: freeparm.c,v 1.5 2007/07/28 18:51:00 babolo Exp $";
#endif /* not lint */

#include <sys/types.h>
#include <stdlib.h>
#include <stdio.h>
#include <babolo/BLINflag.h>
#include "parser.h"

void
babolo_freeparm(babolo_parm *parm) {
    int i;

    if  (parm) {
        ifBLIN_QV4(parm->flag) fprintf( stderr
                                      , "+babolo_freeparm flag=%08X argc=%d\n"
                                      , parm->flag
                                      , parm->argc
                                      );
        if  (parm->argv) {
            if  (parm->flag & Bpars_CHNK) free(*parm->argv);
            else
                for (i = 0; i < parm->argc; i++) {
                    free(parm->argv[i]);
                }
            free(parm->argv);
        }
        free(parm);
        ifBLIN_QV4(parm->flag) fprintf(stderr, "-babolo_freeparm\n");
}   }
